..
.. January 15 2018, Christian Hopps <chopps@gmail.com>
..

#######
netconf
#######

This package supports creating both netconf clients and servers. Additionally a
CLI netconf utility is included.

Additionally `netconf` uses `_sshutil` and thus supports your SSH agent and SSH
config when using the client as well as socket caching for optimal performance.

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage-cli
   develop
   reference

.. _sshutil: https://github.com/choppsv1/pysshutil
